@@ -39,8 +39,6 @@ INGRESS_INTERNAL_AND_CLOUD_LOAD_BALANCING = 'internal-and-cloud-load-balancing'
 SERVICE_MIN_SCALE_ANNOTATION = 'run.googleapis.com/minScale'
 SERVICE_MAX_SCALE_ANNOTATION = 'run.googleapis.com/maxScale'
 MANUAL_INSTANCE_COUNT_ANNOTATION = 'run.googleapis.com/manualInstanceCount'
-SERVICE_MAX_SURGE_ANNOTATION = 'run.googleapis.com/max-surge'
-SERVICE_MAX_UNAVAILABLE_ANNOTATION = 'run.googleapis.com/max-unavailable'
 SERVICE_SCALING_MODE_ANNOTATION = 'run.googleapis.com/scalingMode'
 OPERATION_ID_ANNOTATION = 'run.googleapis.com/operation-id'
 PRESETS_ANNOTATION = 'run.googleapis.com/presets'
